@@ -9,6 +9,7 @@ from typing import Dict, Generator, Optional, Tuple, Union
 from urllib.parse import urljoin
 
 import pandas as pd
+import pytz
 from requests import HTTPError
 
 from wetterdienst.core.scalar.request import ScalarRequestCore
@@ -133,7 +134,8 @@ class DwdMosmixValues(ScalarValuesCore):
             if self.sr.stations.tidy:
                 df = self.tidy_up_df(df, self.sr.stations.mosmix_type)
 
-            station_id = df[Columns.STATION_ID.value][0]
+            station_id = df[Columns.STATION_ID.value].iloc[0]
+
             df = self._organize_df_columns(df, station_id, self.sr.stations.mosmix_type)
 
             df = self._coerce_meta_fields(df)
@@ -141,6 +143,13 @@ class DwdMosmixValues(ScalarValuesCore):
             if self.sr.humanize:
                 df = self._humanize(df, hpm)
 
+            # Filter for dates range if start_date and end_date are defined
+            if not df.empty and self.sr.start_date and self.sr.start_date != DwdForecastDate.LATEST:
+                df = df.loc[
+                    (df[Columns.DATE.value] >= self.sr.start_date) & (df[Columns.DATE.value] <= self.sr.end_date),
+                    :,
+                ]
+
             yield ValuesResult(stations=self.sr, df=df)
 
     def _collect_station_parameter(self) -> Generator[pd.DataFrame, None, None]:
@@ -278,6 +287,8 @@ class DwdMosmixValues(ScalarValuesCore):
             except IndexError as e:
                 raise IndexError(f"Unable to find LATEST file within {url}") from e
 
+        date = date.astimezone(pytz.UTC).replace(tzinfo=None)
+
         df_urls = pd.DataFrame({"URL": urls})
 
         df_urls[DwdColumns.DATE.value] = df_urls["URL"].apply(
@@ -407,7 +418,7 @@ class DwdMosmixRequest(ScalarRequestCore):
 
         try:
             start_issue = parse_enumeration_from_template(start_issue, DwdForecastDate)
-        except InvalidParameter:
+        except (InvalidParameter, KeyError, ValueError):
             pass
 
         # Parse issue date if not set to fixed "latest" string
